@@ -13,13 +13,14 @@ typedef Eo Efl_Canvas_Surface_Wayland;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Native Wayland surface for Efl canvas
  *
  * @ingroup Efl_Canvas_Surface_Wayland
  */
 #define EFL_CANVAS_SURFACE_WAYLAND_CLASS efl_canvas_surface_wayland_class_get()
 
-EWAPI const Eo_Class *efl_canvas_surface_wayland_class_get(void);
-
+EWAPI const Efl_Class *efl_canvas_surface_wayland_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
